pub struct DirConnector { /* private fields */ }Expand description
A capability to obtain a channel to a [fuchsia.io/Directory]. As the name suggests, this is
similar to [Connector], except the channel type is always [fuchsia.io/Directory], and vfs
nodes that wrap this capability should have the DIRECTORY entry_type.
Implementations
Sourceimpl DirConnector
impl DirConnector
pub fn new() -> (DirReceiver, Arc<Self>)
pub fn from_proxy( proxy: DirectoryProxy, subdir: RelativePath, flags: Flags, ) -> Arc<Self> ⓘ
pub fn new_sendable(connector: impl DirConnectable + 'static) -> Arc<Self> ⓘ
pub fn send( &self, dir: ServerEnd<DirectoryMarker>, subdir: RelativePath, flags: Option<Flags>, ) -> Result<(), ()>
pub fn with_subdir(self: Arc<Self>, subdir: RelativePath) -> Arc<Self> ⓘ
Sourceimpl DirConnector
impl DirConnector
pub fn from_directory_entry( directory_entry: Arc<dyn DirectoryEntry>, flags: Flags, ) -> Arc<Self> ⓘ