pub struct Router<T: CapabilityBound> { /* private fields */ }Expand description
A Router is a capability that lets the holder obtain other capabilities
asynchronously. Router is the object capability representation of
Routable.
During routing, a request usually traverses through the component topology, passing through several routers, ending up at some router that will fulfill the request instead of forwarding it upstream.
Implementations
Sourceimpl<T: CapabilityBound> Router<T>
impl<T: CapabilityBound> Router<T>
Sourcepub fn new_error(error: impl Into<RouterError>) -> Arc<Self> ⓘ
pub fn new_error(error: impl Into<RouterError>) -> Arc<Self> ⓘ
Creates a router that will always fail a request with the provided error.
Sourcepub fn new_debug(source: CapabilitySource) -> Arc<Self> ⓘ
pub fn new_debug(source: CapabilitySource) -> Arc<Self> ⓘ
Creates a router that will always return the given debug info.
Sourcepub async fn route(
&self,
request: RouteRequest,
target: Arc<WeakInstanceToken>,
) -> Result<Option<Arc<T>>, RouterError>
pub async fn route( &self, request: RouteRequest, target: Arc<WeakInstanceToken>, ) -> Result<Option<Arc<T>>, RouterError>
Obtain a capability from this router, following the description in request.
Sourcepub async fn route_debug(
&self,
request: RouteRequest,
target: Arc<WeakInstanceToken>,
) -> Result<CapabilitySource, RouterError>
pub async fn route_debug( &self, request: RouteRequest, target: Arc<WeakInstanceToken>, ) -> Result<CapabilitySource, RouterError>
Obtain a CapabilitySource from this router, following the description in request.
Sourceimpl<T: CapabilityBound> Router<T>
impl<T: CapabilityBound> Router<T>
Sourceimpl Router<Connector>
impl Router<Connector>
Sourcepub fn serve_and_register(
self: Arc<Self>,
stream: ConnectorRouterRequestStream,
koid: Koid,
token: Arc<WeakInstanceToken>,
)
pub fn serve_and_register( self: Arc<Self>, stream: ConnectorRouterRequestStream, koid: Koid, token: Arc<WeakInstanceToken>, )
Serves the fuchsia.sandbox.Router protocol and moves ourself into the registry.
Sourceimpl Router<Data>
impl Router<Data>
Sourcepub fn serve_and_register(
self: Arc<Self>,
stream: DataRouterRequestStream,
koid: Koid,
token: Arc<WeakInstanceToken>,
)
pub fn serve_and_register( self: Arc<Self>, stream: DataRouterRequestStream, koid: Koid, token: Arc<WeakInstanceToken>, )
Serves the fuchsia.sandbox.Router protocol and moves ourself into the registry.
Sourceimpl Router<Dictionary>
impl Router<Dictionary>
Sourcepub fn serve_and_register(
self: Arc<Self>,
stream: DictionaryRouterRequestStream,
koid: Koid,
token: Arc<WeakInstanceToken>,
)
pub fn serve_and_register( self: Arc<Self>, stream: DictionaryRouterRequestStream, koid: Koid, token: Arc<WeakInstanceToken>, )
Serves the fuchsia.sandbox.Router protocol and moves ourself into the registry.
Sourceimpl Router<DirConnector>
impl Router<DirConnector>
Sourcepub fn serve_and_register(
self: Arc<Self>,
stream: DirConnectorRouterRequestStream,
koid: Koid,
token: Arc<WeakInstanceToken>,
)
pub fn serve_and_register( self: Arc<Self>, stream: DirConnectorRouterRequestStream, koid: Koid, token: Arc<WeakInstanceToken>, )
Serves the fuchsia.sandbox.Router protocol and moves ourself into the registry.