Router

Struct Router 

pub struct Router<T: CapabilityBound> { /* private fields */ }
A Router is a capability that lets the holder obtain other capabilities asynchronously. Router is the object capability representation of Routable.

During routing, a request usually traverses through the component topology, passing through several routers, ending up at some router that will fulfill the request instead of forwarding it upstream.

Implementations

Source

impl<T: CapabilityBound> Router<T>

pub fn new(routable: impl Routable<T> + 'static) -> Self

Package a Routable object into a Router.

pub fn new_error(error: impl Into<RouterError>) -> Self

Creates a router that will always fail a request with the provided error.

pub fn new_debug(source: CapabilitySource) -> Self

Creates a router that will always return the given debug info.

pub async fn route( &self, request: RouteRequest, target: WeakInstanceToken, ) -> Result<Option<T>, RouterError>

Obtain a capability from this router, following the description in request.

pub async fn route_debug( &self, request: RouteRequest, target: WeakInstanceToken, ) -> Result<CapabilitySource, RouterError>

Obtain a CapabilitySource from this router, following the description in request.

Source

impl<T: Clone + CapabilityBound> Router<T>

pub fn new_ok(c: impl Into<T>) -> Self

Creates a router that will always resolve with the provided capability.

Source

impl Router<Connector>

pub fn serve_and_register( self, stream: ConnectorRouterRequestStream, koid: Koid, token: WeakInstanceToken, )

Serves the fuchsia.sandbox.Router protocol and moves ourself into the registry.

Source

impl Router<Data>

pub fn serve_and_register( self, stream: DataRouterRequestStream, koid: Koid, token: WeakInstanceToken, )

Serves the fuchsia.sandbox.Router protocol and moves ourself into the registry.

Source

impl Router<Dictionary>

pub fn serve_and_register( self, stream: DictionaryRouterRequestStream, koid: Koid, token: WeakInstanceToken, )

Serves the fuchsia.sandbox.Router protocol and moves ourself into the registry.

Source

impl Router<DirConnector>

pub fn serve_and_register( self, stream: DirConnectorRouterRequestStream, koid: Koid, token: WeakInstanceToken, )

Serves the fuchsia.sandbox.Router protocol and moves ourself into the registry.