pub struct RouterErrorInfo {
pub capability_type: CapabilityTypeName,
pub name: Name,
pub availability: Availability,
}Expand description
Diagnostic data derived from the capability decl used to instantiate the router.
Fields
capability_type: CapabilityTypeNamename: NameThe capability name. The semantics of this name depends on the type of the decl:
- Expose ->
target_name - Offer ->
target_name - Capability ->
name - Use ->
source_name
availability: AvailabilityTrait Implementations
Sourceimpl Clone for RouterErrorInfo
impl Clone for RouterErrorInfo
Sourcefn clone(&self) -> RouterErrorInfo
fn clone(&self) -> RouterErrorInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RouterErrorInfo
impl Debug for RouterErrorInfo
impl Eq for RouterErrorInfo
Sourceimpl PartialEq for RouterErrorInfo
impl PartialEq for RouterErrorInfo
Sourcefn eq(&self, other: &RouterErrorInfo) -> bool
fn eq(&self, other: &RouterErrorInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RouterErrorInfo