Routable

Trait Routable 

pub trait Routable<T>: Send + Sync
where T: CapabilityBound,
{ // Required methods fn route<'life0, 'async_trait>( &'life0 self, request: RouteRequest, target: WeakInstanceToken, ) -> Pin<Box<dyn Future<Output = Result<Option<T>, RouterError>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn route_debug<'life0, 'async_trait>( &'life0 self, request: RouteRequest, target: WeakInstanceToken, ) -> Pin<Box<dyn Future<Output = Result<CapabilitySource, RouterError>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; }
Types that implement Routable let the holder asynchronously request capabilities from them.

Required Methods

fn route<'life0, 'async_trait>( &'life0 self, request: RouteRequest, target: WeakInstanceToken, ) -> Pin<Box<dyn Future<Output = Result<Option<T>, RouterError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn route_debug<'life0, 'async_trait>( &'life0 self, request: RouteRequest, target: WeakInstanceToken, ) -> Pin<Box<dyn Future<Output = Result<CapabilitySource, RouterError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Performs the same operation as route, but returns a fidl_fuchsia_internal::CapabilitySource persisted into bytes.

Implementors